==> ejc-probuilddiary-impl-3.0.0-20220920.034155-21-sources.jar: com/ejianc/business/probuilddiary/ledger/bean/LedgerDetailEntity.java <==
package com.ejianc.business.probuilddiary.ledger.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 日志台账-施工内容（施工员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_ledger_detail")
public class LedgerDetailEntity extends BaseEntity {
	private static final long serialVersionUID = 3189046164125414863L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "construct_id")
	private Long constructId; // 施工区域id
	@TableField(value = "construct_name")
	private String constructName; // 施工区域名称
	@TableField(value = "construct_code")
	private String constructCode; // 施工区域编码
	@TableField(value = "team_name")
	private String teamName; // 施工班组名称
	@TableField(value = "work_num")
	private Integer workNum; // 工作人数
	@TableField(value = "work_memo")
	private String workMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "ledger_id")
	private Long ledgerId; // 日志台账id
	@TableField(value = "file_type")
	private String fileType; // 文件类型
	@TableField(value = "log_number")
	private String logNumber; // 日志项编码
	@TableField(value = "project_manager_flag")
	private Boolean projectManagerFlag; // 项目经理标识
	@TableField(value = "duty_id")
	private Long dutyId; // 责任人id
	@TableField(value = "duty_name")
	private String dutyName; // 责任人名称
	@TableField(value = "duty_code")
	private String dutyCode; // 责任人编码


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getConstructId() {
		return constructId;
	}

	public void setConstructId(Long constructId) {
		this.constructId = constructId;
	}

	public String getConstructName() {
		return constructName;
	}

	public void setConstructName(String constructName) {
		this.constructName = constructName;
	}

	public String getConstructCode() {
		return constructCode;
	}

	public void setConstructCode(String constructCode) {
		this.constructCode = constructCode;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public Integer getWorkNum() {
		return workNum;
	}

	public void setWorkNum(Integer workNum) {
		this.workNum = workNum;
	}

	public String getWorkMemo() {
		return workMemo;
	}

	public void setWorkMemo(String workMemo) {
		this.workMemo = workMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public String getLogNumber() {
		return logNumber;
	}

	public void setLogNumber(String logNumber) {
		this.logNumber = logNumber;
	}

	public Boolean getProjectManagerFlag() {
		return projectManagerFlag;
	}

	public void setProjectManagerFlag(Boolean projectManagerFlag) {
		this.projectManagerFlag = projectManagerFlag;
	}

	public Long getDutyId() {
		return dutyId;
	}

	public void setDutyId(Long dutyId) {
		this.dutyId = dutyId;
	}

	public String getDutyName() {
		return dutyName;
	}

	public void setDutyName(String dutyName) {
		this.dutyName = dutyName;
	}

	public String getDutyCode() {
		return dutyCode;
	}

	public void setDutyCode(String dutyCode) {
		this.dutyCode = dutyCode;
	}
}

==> ejc-probuilddiary-impl-3.0.0-20220923.051842-54-sources.jar: com/ejianc/business/probuilddiary/ledger/bean/LedgerDetailEntity.java <==
package com.ejianc.business.probuilddiary.ledger.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 日志台账-施工内容（施工员）
 *
 * @author baipengyan
 */
@TableName("ejc_probuilddiary_ledger_detail")
public class LedgerDetailEntity extends BaseEntity {
	private static final long serialVersionUID = 3189046164125414863L;

	@TableField(value = "person_id")
	private Long personId; // 个人日志id
	@TableField(value = "construct_id")
	private Long constructId; // 施工区域id
	@TableField(value = "construct_name")
	private String constructName; // 施工区域名称
	@TableField(value = "construct_code")
	private String constructCode; // 施工区域编码
	@TableField(value = "team_name")
	private String teamName; // 施工班组名称
	@TableField(value = "work_num")
	private Integer workNum; // 工作人数
	@TableField(value = "work_memo")
	private String workMemo; // 工作描述
	@TableField(value = "commit_user_id")
	private Long commitUserId; // 提交人id
	@TableField(value = "commit_user_code")
	private String commitUserCode; // 提交人账号
	@TableField(value = "commit_user_name")
	private String commitUserName; // 提交人名称
	@TableField(value = "commit_date")
	private Date commitDate; // 提交日期
	@TableField(value = "project_log_id")
	private Long projectLogId; // 项目日志id
	@TableField(value = "ledger_id")
	private Long ledgerId; // 日志台账id
	@TableField(value = "file_type")
	private String fileType; // 文件类型
	@TableField(value = "log_number")
	private String logNumber; // 日志项编码
	@TableField(value = "project_manager_flag")
	private Boolean projectManagerFlag; // 项目经理标识
	@TableField(value = "duty_id")
	private String dutyId; // 责任人id
	@TableField(value = "duty_name")
	private String dutyName; // 责任人名称
	@TableField(value = "duty_code")
	private String dutyCode; // 责任人编码


	public Long getPersonId() {
		return personId;
	}

	public void setPersonId(Long personId) {
		this.personId = personId;
	}

	public Long getConstructId() {
		return constructId;
	}

	public void setConstructId(Long constructId) {
		this.constructId = constructId;
	}

	public String getConstructName() {
		return constructName;
	}

	public void setConstructName(String constructName) {
		this.constructName = constructName;
	}

	public String getConstructCode() {
		return constructCode;
	}

	public void setConstructCode(String constructCode) {
		this.constructCode = constructCode;
	}

	public String getTeamName() {
		return teamName;
	}

	public void setTeamName(String teamName) {
		this.teamName = teamName;
	}

	public Integer getWorkNum() {
		return workNum;
	}

	public void setWorkNum(Integer workNum) {
		this.workNum = workNum;
	}

	public String getWorkMemo() {
		return workMemo;
	}

	public void setWorkMemo(String workMemo) {
		this.workMemo = workMemo;
	}

	public Long getCommitUserId() {
		return commitUserId;
	}

	public void setCommitUserId(Long commitUserId) {
		this.commitUserId = commitUserId;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public Long getProjectLogId() {
		return projectLogId;
	}

	public void setProjectLogId(Long projectLogId) {
		this.projectLogId = projectLogId;
	}

	public Long getLedgerId() {
		return ledgerId;
	}

	public void setLedgerId(Long ledgerId) {
		this.ledgerId = ledgerId;
	}

	public String getFileType() {
		return fileType;
	}

	public void setFileType(String fileType) {
		this.fileType = fileType;
	}

	public String getLogNumber() {
		return logNumber;
	}

	public void setLogNumber(String logNumber) {
		this.logNumber = logNumber;
	}

	public Boolean getProjectManagerFlag() {
		return projectManagerFlag;
	}

	public void setProjectManagerFlag(Boolean projectManagerFlag) {
		this.projectManagerFlag = projectManagerFlag;
	}

	public String getDutyId() {
		return dutyId;
	}

	public void setDutyId(String dutyId) {
		this.dutyId = dutyId;
	}

	public String getDutyName() {
		return dutyName;
	}

	public void setDutyName(String dutyName) {
		this.dutyName = dutyName;
	}

	public String getDutyCode() {
		return dutyCode;
	}

	public void setDutyCode(String dutyCode) {
		this.dutyCode = dutyCode;
	}
}
